@@ -3,7 +3,7 @@ import json
 from dataclasses import is_dataclass
 from typing import Any, Callable, Dict, Iterator, List, Optional, Set, Tuple, Type, get_type_hints
 
-import typing_inspect  # type: ignore
+import typing_inspect
 from dataclasses_jsonschema import JsonSchemaMixin, ValidationError
 from typed_ast.ast3 import Name
 
@@ -18,16 +18,32 @@ class ObjectTypeException(Arcor2Exception):
     pass
 
 
+def get_containing_module_sources(type_def: Type[Generic]) -> str:
+    """Returns sources of the whole containing module.
+
+    ...whereas inspect.getsource(type_def) returns just source of the class itself
+    :param type_def:
+    :return:
+    """
+
+    with open(inspect.getfile(type_def), "r") as source_file:
+        return source_file.read()
+
+
 def check_object_type(type_def: Type[Generic]) -> None:
     """Checks whether the object type source is a valid one.
 
-    :param object_type_source:
+    :param type_def:
     :return:
     """
 
     if not issubclass(type_def, Generic):
         raise ObjectTypeException("Not a subclass of Generic.")
 
+    # it might happen that the code is ok, but can't be parsed e.g. due to unsupported placement of comment
+    # parse_def is not enough here - there might be something unparseable outside of the ObjectType class itself
+    parse(get_containing_module_sources(type_def))
+
     # TODO some more (simple) checks here?
 
 
