@@ -7,6 +7,9 @@ from arcor2.parameter_plugins.list import ListParameterPlugin, get_type_name
 
 
 class BooleanPlugin(ParameterPlugin):
+
+    COUNTABLE = True
+
     @classmethod
     def type(cls) -> Any:
         return bool
@@ -16,8 +19,14 @@ class BooleanPlugin(ParameterPlugin):
         return "boolean"
 
     @classmethod
-    def value(cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str) -> bool:
-        return cls.type()(super(BooleanPlugin, cls).value(type_defs, scene, project, action_id, parameter_id))
+    def parameter_value(
+        cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
+    ) -> bool:
+        return super(BooleanPlugin, cls).parameter_value(type_defs, scene, project, action_id, parameter_id)
+
+    @classmethod
+    def _value_from_json(cls, value: str) -> bool:
+        return super(BooleanPlugin, cls)._value_from_json(value)
 
 
 class BooleanListPlugin(ListParameterPlugin):
@@ -27,10 +36,10 @@ class BooleanListPlugin(ListParameterPlugin):
 
     @classmethod
     def type_name(cls) -> str:
-        return get_type_name(BooleanPlugin)
+        return get_type_name(BooleanPlugin)  # type: ignore
 
     @classmethod
-    def value(
+    def parameter_value(
         cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
     ) -> List[bool]:
-        return super(BooleanListPlugin, cls).value(type_defs, scene, project, action_id, parameter_id)
+        return super(BooleanListPlugin, cls).parameter_value(type_defs, scene, project, action_id, parameter_id)
