@@ -16,8 +16,10 @@ class StringPlugin(ParameterPlugin):
         return "string"
 
     @classmethod
-    def value(cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str) -> str:
-        return cls.type()(super(StringPlugin, cls).value(type_defs, scene, project, action_id, parameter_id))
+    def parameter_value(
+        cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
+    ) -> str:
+        return super(StringPlugin, cls).parameter_value(type_defs, scene, project, action_id, parameter_id)
 
 
 class StringListPlugin(ListParameterPlugin):
@@ -27,10 +29,10 @@ class StringListPlugin(ListParameterPlugin):
 
     @classmethod
     def type_name(cls) -> str:
-        return get_type_name(StringPlugin)
+        return get_type_name(StringPlugin)  # type: ignore
 
     @classmethod
-    def value(
+    def parameter_value(
         cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
     ) -> List[str]:
-        return super(StringListPlugin, cls).value(type_defs, scene, project, action_id, parameter_id)
+        return super(StringListPlugin, cls).parameter_value(type_defs, scene, project, action_id, parameter_id)
