@@ -3,7 +3,7 @@ import json
 import os
 from typing import Any, Dict, Optional, Type, TypeVar
 
-import humps  # type: ignore
+import humps
 from dataclasses_jsonschema import JsonSchemaMixin, JsonSchemaValidationError
 
 import arcor2.object_types
@@ -19,14 +19,17 @@ from arcor2.exceptions import Arcor2Exception
 from arcor2.exceptions.runtime import print_exception
 from arcor2.object_types.abstract import Generic, GenericWithPose, Robot
 from arcor2.object_types.utils import built_in_types_names, settings_from_params
-from arcor2.parameter_plugins import PARAM_PLUGINS
 from arcor2.parameter_plugins.base import TypesDict
+from arcor2.parameter_plugins.utils import plugin_from_type_name
 
 
 class ResourcesException(Arcor2Exception):
     pass
 
 
+R = TypeVar("R", bound="IntResources")
+
+
 class IntResources:
 
     CUSTOM_OBJECT_TYPES_MODULE = "object_types"
@@ -112,7 +115,7 @@ class IntResources:
             # Action point pose is relative to its parent object/AP pose in scene but is absolute during runtime.
             tr.make_relative_ap_global(self.scene, self.project, aps)
 
-    def __enter__(self) -> "IntResources":
+    def __enter__(self: R) -> R:
         return self
 
     def __exit__(self, ex_type, ex_value, traceback) -> bool:
@@ -145,7 +148,7 @@ class IntResources:
         ret: Dict[str, Any] = {}
 
         for param in act.parameters:
-            ret[param.name] = PARAM_PLUGINS[param.type].execution_value(
+            ret[param.name] = plugin_from_type_name(param.type).parameter_execution_value(
                 self.type_defs, self.scene, self.project, action_id, param.name
             )
 
