@@ -5,7 +5,7 @@ from collections import deque
 from typing import Any, Awaitable, Callable, Coroutine, Dict, Optional, Set, Tuple, Type, TypeVar
 
 import websockets
-from aiologger.levels import LogLevel  # type: ignore
+from aiologger.levels import LogLevel
 from dataclasses_jsonschema import ValidationError
 
 from arcor2.data.events import Event
@@ -136,6 +136,7 @@ async def server(
                             ignored_reqs.remove(req.request)
 
                     if req.request not in ignored_reqs:
+                        # TODO do not print out too big messages (ideally omit its data part)
                         asyncio.ensure_future(logger.debug(f"RPC request: {req}, result: {resp}"))
 
             elif "event" in data:  # ...event from UI
